@@ -28,7 +28,7 @@ import matplotlib.cm as cm
 
 #from .parser import parse
 
-__version__ = '0.1.19'
+__version__ = '0.1.20'
 
 output_notebook(resources=INLINE)
 #output_notebook()
@@ -372,7 +372,8 @@ def check_dt(quintuples):
 
 def plot(*args, p=None, hover=False, mode='plot', hline=None, vline=None, 
         color=None, hline_color='pink', vline_color='pink', 
-        xlabel=None, ylabel=None, label=None, legend_loc=None, **kwargs):
+        xlabel=None, ylabel=None, label=None, legend_loc=None, 
+        notebook_handle=False, **kwargs):
 #    print('(plot) FIGURE =', FIGURE)
     try:
         #show = p is None
@@ -405,7 +406,6 @@ def plot(*args, p=None, hover=False, mode='plot', hline=None, vline=None,
                     raise ValueError('cannot plot non-datetime x values on a datetime x axis')
 #                print('B')
 
-        notebook_handle = kwargs.pop('notebook_handle', False)
         if hover:
             if is_dt:
                 p.add_tools(HoverTool(tooltips=[('x', '@x{%F}'), ('y', '@y'), ('name', '$name')],
@@ -455,10 +455,13 @@ def plot(*args, p=None, hover=False, mode='plot', hline=None, vline=None,
             p.xaxis.axis_label = xlabel
         if ylabel is not None:
             p.yaxis.axis_label = ylabel
-#        handle = None
-#        if show:
-#            handle = bp.show(p, notebook_handle=notebook_handle)
-        return source if notebook_handle else None
+        handle = None
+        if notebook_handle:
+            handle = bp.show(p, notebook_handle=notebook_handle)
+            FIGURE.clear()
+            return source, handle
+        else:
+            return None
     except ParseError as e:
         print(e)
 
